@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "helm-descbinds" "1.13"
+(define-package "helm-descbinds" "20250705.942"
   "A convenient `describe-bindings' with `helm'."
   '((helm "1.5"))
   :url "https://github.com/emacs-helm/helm-descbinds"
-  :commit "6d5ddc11e6cef86548bd6b3e0d840112d602659c"
-  :revdesc "v1.13-0-g6d5ddc11e6ce"
+  :commit "0aff44badad976ebf2666a7e9b6ddf4db53e59e5"
+  :revdesc "0aff44badad9"
   :keywords '("helm" "help")
   :authors '(("Taiki SUGAWARA" . "buzz.taiki@gmail.com"))
   :maintainers '(("Taiki SUGAWARA" . "buzz.taiki@gmail.com")))
